==> rollup-plugin-ternary-1.0.1.tgz: package/src/index.js <==
import { extname } from 'path';
import acorn from 'acorn-jsx';
import { walk } from 'estree-walker';
import { createFilter } from 'rollup-pluginutils';
import MagicString from 'magic-string';

// from: https://gist.github.com/DavidWells/50b891a9e012a1e748c2
function transform(string) {
  // console.log(`in: ${string}`);
  let questionMark = string.indexOf('?');
  let colon = string.indexOf(':', questionMark);

  if (questionMark === -1 || colon === -1) {
    return string;
  }

  const condition = string.substring(0, questionMark);
  const expressions = string.substring(questionMark + 1, string.length);
  let trueExpression = null;
  let falseExpression = null;

  // console.log("expressions: " + expressions);

  // While looking in pairs, find the location where the colon occurs before the question mark.
  questionMark = expressions.indexOf('?');
  colon = expressions.indexOf(':');
  while ((questionMark !== -1 && colon !== -1) && (questionMark < colon)) {
    questionMark = expressions.indexOf('?', questionMark + 1);
    colon = expressions.indexOf(':', colon + 1);
  }

  // console.log("\t" + "questionMark: " + questionMark);
  // console.log("\t" + "colon: " + colon);

  trueExpression = expressions.substring(0, colon);
  falseExpression = expressions.substring(colon + 1, expressions.length);

  // console.log("condition: " + condition);
  // console.log("trueExpression: " + trueExpression);
  // console.log("falseExpression: " + falseExpression);
  //
  // console.log("-");

  const result = `if (${condition}) {\n${transform(trueExpression)}\n} else {\n${transform(falseExpression)}\n}`;
  // console.log(`out: ${result}`);

  return result;
}

export default function plugin(options = {}) {
  const extensions = options.extensions || ['.js'];
  const filter = createFilter(options.include, options.exclude);
  const sourceMap = options.sourceMap !== false;
  const extra = options.extra || true;

  return {
    transform: (code, id) => {
      if (!filter(id)) {
        return null;
      }
      if (extensions.indexOf(extname(id)) === -1) {
        return null;
      }

      let ast;

      try {
        ast = acorn.parse(code, {
          ecmaVersion: 6,
          sourceType: 'module',
          plugins: {
            jsx: true
          }
        });
      } catch (err) {
        err.message += ` in ${id}`;
        throw err;
      }

      const magicString = new MagicString(code);

      walk(ast, {
        enter: (node) => {
          if (node.type === 'ConditionalExpression') {
            if (extra && node.consequent.type !== 'ConditionalExpression') {
              return;
            }

            if (sourceMap) {
              magicString.addSourcemapLocation(node.start);
              magicString.addSourcemapLocation(node.end);
            }

            // console.log(`\nfile: ${id}`);
            const converted = transform(code.slice(node.start, node.end));
            magicString.overwrite(node.start, node.end, converted);
            return;
          }
        }
      });

      const resultCode = magicString.toString();
      const map = sourceMap ? magicString.generateMap() : null;

      return {
        code: resultCode,
        map: map
      };
    }
  };
}

==> rollup-plugin-ternary-2.0.1.tgz: package/src/index.js <==
import { extname } from 'path';
import acorn from 'acorn-jsx';
import { walk } from 'estree-walker';
import { createFilter } from 'rollup-pluginutils';
import MagicString from 'magic-string';
import escodegen from 'escodegen';

function convert(ast) {
  let trueExpression;
  let falseExpression;
  const condition = escodegen.generate(ast.test);

  if (ast.consequent.type === 'ConditionalExpression') {
    trueExpression = convert(ast.consequent);
  } else {
    trueExpression = escodegen.generate(ast.consequent);
  }

  if (ast.alternate.type === 'ConditionalExpression') {
    falseExpression = convert(ast.alternate);
  } else {
    falseExpression = escodegen.generate(ast.alternate);
  }

  return `if (${condition}) {\n${trueExpression}\n} else {\n${falseExpression}\n}`;
}

export default function plugin(options = {}) {
  const extensions = options.extensions || ['.js'];
  const filter = createFilter(options.include, options.exclude);
  const sourceMap = options.sourceMap !== false;
  const extra = options.extra !== false;

  return {
    transform: (code, id) => {
      if (!filter(id)) {
        return null;
      }
      if (extensions.indexOf(extname(id)) === -1) {
        return null;
      }

      let ast;

      try {
        ast = acorn.parse(code, {
          ecmaVersion: 6,
          sourceType: 'module',
          plugins: {
            jsx: true
          }
        });
      } catch (err) {
        err.message += ` in ${id}`;
        throw err;
      }

      const magicString = new MagicString(code);

      walk(ast, {
        enter: (node) => {
          if (node.type === 'ConditionalExpression') {
            if (extra && node.consequent.type !== 'ConditionalExpression') {
              return;
            }

            if (sourceMap) {
              magicString.addSourcemapLocation(node.start);
              magicString.addSourcemapLocation(node.end);
            }

            const converted = convert(node);
            magicString.overwrite(node.start, node.end, converted);
            return;
          }
        }
      });

      const resultCode = magicString.toString();
      const map = sourceMap ? magicString.generateMap() : null;

      return {
        code: resultCode,
        map: map
      };
    }
  };
}
